@@ -4,12 +4,12 @@ function (y, trt, DFerror, MSerror, alpha=0.05, group=TRUE,main = NULL)
     name.y <- paste(deparse(substitute(y)))
     name.t <- paste(deparse(substitute(trt)))
     junto <- subset(data.frame(y, trt), is.na(y) == FALSE)
-    means <- tapply.stat(junto[,2],junto[,1],mean)
-    sds <-   tapply.stat(junto[,2],junto[,1],sd)
-    nn <-   tapply.stat(junto[,2],junto[,1],length)
+    means <- tapply.stat(junto[,2],junto[,1],stat="mean")
+    sds <-   tapply.stat(junto[,2],junto[,1],stat="sd")
+    nn <-   tapply.stat(junto[,2],junto[,1],stat="length")
     means<-data.frame(means,std.err=sds[,2]/sqrt(nn[,2]),replication=nn[,2])
     names(means)[1:2]<-c(name.t,name.y)
-    row.names(means)<-means[,1]
+#   row.names(means)<-means[,1]
     ntr<-nrow(means)
     Tprob <- qtukey(1-alpha,ntr, DFerror)
     nr <- unique(nn[,2])
